@@ -2,20 +2,20 @@
  *
  * Copyright (C) 2003 - 2007 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include <string.h>
@@ -728,9 +728,11 @@ gda_dict_load_xml_file (GdaDict *dict, const gchar *xmlfile, GError **error)
 		xmlcheck = xmlDoValidityCheckingDefaultValue;
 		xmlDoValidityCheckingDefaultValue = 1;
 
-		/* replace the DTD with ours */
-		old_dtd = doc->intSubset;
-		doc->intSubset = gda_dict_dtd;
+		/* replace the DTD with ours if necessary */
+		if (gda_dict_dtd) {
+			old_dtd = doc->intSubset;
+			doc->intSubset = gda_dict_dtd;
+		}
 
 		if (! xmlValidateDocument (validc, doc)) {
 			gchar *str;
@@ -876,7 +878,8 @@ gda_dict_load_xml_file (GdaDict *dict, const gchar *xmlfile, GError **error)
 
 		subnode = subnode->next;
 	}
-	doc->intSubset = old_dtd;
+	if (gda_dict_dtd)
+		doc->intSubset = old_dtd;
 	xmlFreeDoc (doc);
 
 	return TRUE;
@@ -925,7 +928,6 @@ gda_dict_save_xml_file (GdaDict *dict, const gchar *xmlfile, GError **error)
 {
 	gboolean retval = TRUE;
 	xmlDocPtr doc;
-#define LIBGDA_DICT_DTD_FILE DTDINSTALLDIR"/libgda-dict.dtd"
 
 	g_return_val_if_fail (dict && GDA_IS_DICT (dict), FALSE);
 	g_return_val_if_fail (dict->priv, FALSE);
@@ -935,7 +937,7 @@ gda_dict_save_xml_file (GdaDict *dict, const gchar *xmlfile, GError **error)
 		xmlNodePtr topnode, node;
 
 		/* DTD insertion */
-                xmlCreateIntSubset(doc, (xmlChar*)"gda_dict", NULL, (xmlChar*)"libgda-dict.dtd"/*LIBGDA_DICT_DTD_FILE*/);
+                xmlCreateIntSubset(doc, (xmlChar*)"gda_dict", NULL, (xmlChar*)"libgda-dict.dtd");
 
 		/* Top node */
 		topnode = xmlNewDocNode (doc, NULL, (xmlChar*)"gda_dict", NULL);
