@@ -2,20 +2,20 @@
  *
  * Copyright (C) 2003 - 2006 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 
@@ -53,6 +53,10 @@ struct _GdaParameterClass
 {
 	GdaObjectClass             parent_class;
 	void                     (*restrict_changed)         (GdaParameter *param);
+	void                     (*reserved_0)               (GdaParameter *param);
+	void                     (*reserved_1)               (GdaParameter *param);
+	void                     (*reserved_2)               (GdaParameter *param);
+	void                     (*reserved_3)               (GdaParameter *param);
 };
 
 GType                  gda_parameter_get_type                (void);
@@ -63,11 +67,8 @@ GType                  gda_parameter_get_g_type              (GdaParameter *para
 GdaParameter          *gda_parameter_new_string              (const gchar *name, const gchar *str);
 GdaParameter          *gda_parameter_new_boolean             (const gchar *name, gboolean value);
 
-void                   gda_parameter_declare_param_user      (GdaParameter *param, GdaObject *user);
-GSList                *gda_parameter_get_param_users         (GdaParameter *param);
-void                   gda_parameter_replace_param_users     (GdaParameter *param, GHashTable *replacements);
-
 const GValue          *gda_parameter_get_value               (GdaParameter *param);
+gchar                 *gda_parameter_get_value_str           (GdaParameter *param);
 void                   gda_parameter_set_value               (GdaParameter *param, const GValue *value);
 gboolean               gda_parameter_set_value_str           (GdaParameter *param, const gchar *value);
 
