@@ -583,13 +583,16 @@ gda_server_operation_set_property (GObject *object,
 				xmlDoValidityCheckingDefaultValue = 1;
 				
 				/* replace the DTD with ours */
-				old_dtd = doc->intSubset;
-				doc->intSubset = gda_server_op_dtd;
+				if (gda_server_op_dtd) {
+					old_dtd = doc->intSubset;
+					doc->intSubset = gda_server_op_dtd;
+				}
 
-				if (! xmlValidateDocument (validc, doc)) {
+				if (doc->intSubset && !xmlValidateDocument (validc, doc)) {
 					gchar *str;
 					
-					doc->intSubset = old_dtd;
+					if (gda_server_op_dtd)
+						doc->intSubset = old_dtd;
 					xmlFreeDoc (doc);
 					g_free (validc);
 					str = g_object_get_data (G_OBJECT (op), "xmlerror");
@@ -609,7 +612,8 @@ gda_server_operation_set_property (GObject *object,
 				
 				xmlDoValidityCheckingDefaultValue = xmlcheck;
 				g_free (validc);
-				doc->intSubset = old_dtd;
+				if (gda_server_op_dtd)
+					doc->intSubset = old_dtd;
 				op->priv->xml_spec_doc = doc;
 			}
 			else {
@@ -1513,8 +1517,6 @@ gda_server_operation_get_node_path_portion (GdaServerOperation *op, const gchar
  * gda_server_operation_get_sequence_item_names
  * @op: a #GdaServerOperation object
  * @path: a complete path to a sequence node (starting with "/")
- * @size: a place to store the current number of elements in the sequence, or %NULL
- * @name: a place to store the name of the sequence (don't free it), or %NULL
  *
  * Fetch the contents of a sequence. @path can describe either a sequence (for example "/SEQNAME") or an item in a sequence
  * (for example "/SEQNAME/3")
