@@ -1,5 +1,5 @@
 /* GDA mSQL Provider
- * Copyright (C) 1998 - 2005 The GNOME Foundation
+ * Copyright (C) 1998 - 2006 The GNOME Foundation
  *
  * AUTHORS:
  * 	   Danilo Schoeneberg <dj@starfire-programming.net
@@ -20,14 +20,14 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include <stdlib.h>
 #include <string.h>
 #include "gda-msql.h"
 #include "gda-msql-recordset.h"
-#include "gda-data-model-private.h"
+#include <libgda/gda-data-model-private.h>
 
-#define PARENT_TYPE GDA_TYPE_DATA_MODEL_BASE
+#define PARENT_TYPE GDA_TYPE_DATA_MODEL_ROW
 
 
 static GObjectClass *parent_class;
@@ -64,45 +64,45 @@ fetch_row (GdaMsqlRecordset *rs,gulong rownum)
 	if (!msql_row) return NULL;
 	for(i=0,msql_fields=rs->res->fieldData;msql_fields;
 	    i++,msql_fields=msql_fields->next) {
-		GdaValue *field;
+		GValue *field;
 		gchar    *s_val;
 
-		field=(GdaValue*)gda_row_get_value(row,i);
+		field=(GValue*)gda_row_get_value(row,i);
 		s_val=msql_row[i];
 		switch (msql_fields->field.type) {
-		case INT_TYPE:  gda_value_set_integer(field, (s_val) ? atol(s_val) : 0);
+		case INT_TYPE:  g_value_set_int(field, (s_val) ? atol(s_val) : 0);
 			break;
-		case UINT_TYPE: gda_value_set_uinteger(field,
-						       (s_val) ? (guint)atol(s_val) : 0);
+		case UINT_TYPE: g_value_set_uint(field,
+						 (s_val) ? (guint)atol(s_val) : 0);
 			break;
-		case REAL_TYPE:  gda_value_set_double(field,(s_val) ? atof(s_val) : 0.0);
+		case REAL_TYPE:  g_value_set_double(field,(s_val) ? atof(s_val) : 0.0);
 			break;
-		case MONEY_TYPE :gda_value_set_single(field,(s_val) ? atof(s_val) : 0.0f);
+		case MONEY_TYPE :g_value_set_float(field,(s_val) ? atof(s_val) : 0.0f);
 			break;
 #ifdef HAVE_MSQL3
-		case IPV4_TYPE:  gda_value_set_string(field,(s_val) ? s_val : "");
+		case IPV4_TYPE:  g_value_set_string(field,(s_val) ? s_val : "");
 			break;
-		case INT64_TYPE: gda_value_set_bigint(field,
-						      (s_val) ? (gint64)atof(s_val) : 0);
+		case INT64_TYPE: g_value_set_int64(field,
+						   (s_val) ? (gint64)atof(s_val) : 0);
 			break;
-		case UINT64_TYPE: gda_value_set_biguint(field,
-							(s_val) ? (guint64)atof(s_val) : 0);
+		case UINT64_TYPE: g_value_set_uint64(field,
+						     (s_val) ? (guint64)atof(s_val) : 0);
                         break;
-		case INT16_TYPE:  gda_value_set_smallint(field,
-							 (s_val) ? (gshort)atol(s_val) : 0);
+		case INT16_TYPE:  gda_value_set_short(field,
+						      (s_val) ? (gshort)atol(s_val) : 0);
                         break;
-		case UINT16_TYPE: gda_value_set_smalluint(field,
-							  (s_val) ? (gushort)atol(s_val) : 0);
+		case UINT16_TYPE: gda_value_set_ushort(field,
+						       (s_val) ? (gushort)atol(s_val) : 0);
                         break;
-		case INT8_TYPE:   gda_value_set_tinyint(field,
-							(s_val) ? (gchar)atol(s_val) : 0);
+		case INT8_TYPE:   g_value_set_char(field,
+						   (s_val) ? (gchar)atol(s_val) : 0);
                         break;
-		case UINT8_TYPE:  gda_value_set_tinyuint(field,
-							 (s_val) ? (guchar)atol(s_val) : 0);
+		case UINT8_TYPE:  g_value_set_uchar(field,
+						    (s_val) ? (guchar)atol(s_val) : 0);
                         break;
 #endif
 		default:
-			gda_value_set_string(field,(s_val) ? s_val : "");
+			g_value_set_string(field,(s_val) ? s_val : "");
 		}  
 	}
 	return row;
@@ -113,7 +113,7 @@ fetch_row (GdaMsqlRecordset *rs,gulong rownum)
  */
 
 static gint 
-gda_msql_recordset_numrows(GdaDataModel *model) 
+gda_msql_recordset_numrows(GdaDataModelRow *model) 
 {
 	GdaMsqlRecordset *rs=(GdaMsqlRecordset*)model;
   
@@ -123,7 +123,7 @@ gda_msql_recordset_numrows(GdaDataModel *model)
 }
 
 static gint
-gda_msql_recordset_numcols(GdaDataModel *model) 
+gda_msql_recordset_numcols(GdaDataModelRow *model) 
 {
 	GdaMsqlRecordset *rs=(GdaMsqlRecordset*)model;
   
@@ -132,8 +132,8 @@ gda_msql_recordset_numcols(GdaDataModel *model)
 	return msqlNumFields(rs->res);
 }
 
-static const GdaRow *
-gda_msql_recordset_get_row(GdaDataModelBase *model,gint row) 
+static GdaRow *
+gda_msql_recordset_get_row(GdaDataModelRow *model, gint row, GError **error) 
 {
 	gint              rows, fetched_rows;
 	register gint     i;
@@ -145,7 +145,7 @@ gda_msql_recordset_get_row(GdaDataModelBase *model,gint row)
 	fetched_rows=rs->rows->len;
 	if (row>=rows) return NULL;
 	if (row<fetched_rows) {
-		return (const GdaRow*)g_ptr_array_index(rs->rows,row);
+		return (GdaRow *) g_ptr_array_index(rs->rows,row);
 	}
 	gda_data_model_freeze(GDA_DATA_MODEL(rs));
 	for(i=fetched_rows;i<=row;i++) {
@@ -154,11 +154,11 @@ gda_msql_recordset_get_row(GdaDataModelBase *model,gint row)
 		g_ptr_array_add(rs->rows,fields);
 	}
 	gda_data_model_thaw(GDA_DATA_MODEL(rs));
-	return (const GdaRow*)fields;
+	return (GdaRow *) fields;
 }
 
-static const GdaValue *
-gda_msql_recordset_get_value_at(GdaDataModelBase *model,gint col,gint row) 
+static const GValue *
+gda_msql_recordset_get_value_at(GdaDataModelRow *model,gint col,gint row) 
 {
 	gint              cols;
 	const GdaRow     *fields;
@@ -167,23 +167,27 @@ gda_msql_recordset_get_value_at(GdaDataModelBase *model,gint col,gint row)
 	if (!GDA_IS_MSQL_RECORDSET(rs)) return NULL;
 	cols=msqlNumFields(rs->res);
 	if (col>=cols) return NULL;
-	fields=gda_msql_recordset_get_row(model,row);
+	fields=gda_msql_recordset_get_row (model,row, NULL);
 	return (fields) ? gda_row_get_value((GdaRow*)fields,col) : NULL;
 }
 
 static gboolean
-gda_msql_recordset_is_updatable(GdaDataModelBase *model) 
+gda_msql_recordset_is_updatable(GdaDataModelRow *model) 
 {
 	GdaCommandType    cmd_type;
 	GdaMsqlRecordset *rs=(GdaMsqlRecordset*)model;
   
 	if (!GDA_IS_MSQL_RECORDSET(rs)) return FALSE;
-	cmd_type=gda_data_model_get_command_type(model);
-	return (cmd_type==GDA_COMMAND_TYPE_TABLE) ? TRUE : FALSE;
+
+	g_object_get (G_OBJECT (model), "command_type", &cmd_type, NULL);
+	return FALSE;
+	/*return (cmd_type==GDA_COMMAND_TYPE_TABLE) ? TRUE : FALSE;*/
 }
 
-static const GdaRow *
-gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values) 
+/* Not implemented. See bug http://bugzilla.gnome.org/show_bug.cgi?id=411811: */
+#if 0
+static GdaRow *
+gda_msql_recordset_append_values(GdaDataModelRow *model,const GList *values, GError **error) 
 {
 	GString          *sql;
 	GdaRow           *row;
@@ -193,8 +197,7 @@ gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values)
 	GdaMsqlRecordset *rs=(GdaMsqlRecordset*)model;
   
 	if ((!GDA_IS_MSQL_RECORDSET(rs)) ||
-	    (!values) || (!gda_data_model_is_updatable(model)) ||
-	    (!gda_data_model_has_changed(model))) {
+	    (!values) || (!gda_data_model_is_updatable ((GdaDataModel*) model))) {
 		return NULL;
 	}
 	cols=msqlNumFields(rs->res);
@@ -204,12 +207,12 @@ gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values)
 		return NULL;
 	}
 	sql=g_string_new("INSERT INTO ");
-	sql=g_string_append(sql,gda_data_model_get_command_text(model));
+	sql=g_string_append(sql,gda_data_model_get_command_text((GdaDataModel*) model));
 	sql=g_string_append(sql,"(");
 	for(i=0;i<cols;i++) {
 		GdaColumn *fa;
     
-		fa= gda_data_model_describe_column(model,i);
+		fa= gda_data_model_describe_column((GdaDataModel*) model,i);
 		if (!fa) {
 			gda_connection_add_event_string(rs->cnc,
 							_("Could not retrieve column's information"));
@@ -223,7 +226,7 @@ gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values)
 	sql = g_string_append(sql,") VALUES (");
 	for (lst = (GList*)values , i=0 ; i<cols ; i++, lst = lst->next) {
 		char           *val_str;
-		const GdaValue *val=(const GdaValue*)lst->data;
+		const GValue *val=(const GValue*)lst->data;
    
 		if (!val) {
 			gda_connection_add_event_string(rs->cnc,
@@ -232,7 +235,7 @@ gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values)
 			return NULL;
 		}
 		if (i) sql=g_string_append(sql,",");
-		val_str=gda_msql_value_to_sql_string((GdaValue*)val);
+		val_str=gda_msql_value_to_sql_string((GValue*)val);
 		sql=g_string_append(sql,val_str);
 		g_free(val_str);
 	}
@@ -243,19 +246,20 @@ gda_msql_recordset_append_values(GdaDataModelBase *model,const GList *values)
 		gda_connection_add_event(rs->cnc,gda_msql_make_error(rc));
 		return NULL;
 	}
-	row=gda_row_new_from_list(model,values);
+	row=gda_row_new_from_list((GdaDataModel*) model,values);
 	g_ptr_array_add(rs->rows,row);
-	return (const GdaRow*)row;
+	return (GdaRow *) row;
 }
+#endif
 
 static gboolean 
-gda_msql_recordset_remove_row (GdaDataModelBase *model,const GdaRow *row) 
+gda_msql_recordset_remove_row (GdaDataModelRow *model, GdaRow *row, GError **error) 
 {
 	return FALSE;
 }
 
 static gboolean
-gda_msql_recordset_update_row (GdaDataModelBase *model,const GdaRow *row) 
+gda_msql_recordset_update_row (GdaDataModelRow *model, GdaRow *row, GError **error) 
 {
 	return FALSE;
 }
@@ -264,7 +268,7 @@ static void
 gda_msql_recordset_class_init (GdaMsqlRecordsetClass *cl) 
 {
 	GObjectClass *obj_class=G_OBJECT_CLASS(cl);
-	GdaDataModelBaseClass *mdl_class=GDA_DATA_MODEL_BASE_CLASS(cl);
+	GdaDataModelRowClass *mdl_class=GDA_DATA_MODEL_ROW_CLASS(cl);
 
 	parent_class = g_type_class_peek_parent(cl);
 	obj_class->finalize = gda_msql_recordset_finalize;
@@ -273,7 +277,10 @@ gda_msql_recordset_class_init (GdaMsqlRecordsetClass *cl)
 	mdl_class->get_row = gda_msql_recordset_get_row;
 	mdl_class->get_value_at = gda_msql_recordset_get_value_at;
 	mdl_class->is_updatable = gda_msql_recordset_is_updatable;
-	mdl_class->append_values = gda_msql_recordset_append_values;
+
+        /* Not implemented. See bug http://bugzilla.gnome.org/show_bug.cgi?id=411811: */
+	mdl_class->append_values = /* gda_msql_recordset_append_values */ NULL;
+
 	mdl_class->remove_row = gda_msql_recordset_remove_row;
 	mdl_class->update_row = gda_msql_recordset_update_row;
 }
@@ -298,7 +305,8 @@ gda_msql_recordset_finalize(GObject *object)
 		rs->res = NULL;
 		for(;rs->rows->len;) {
 			GdaRow *row = (GdaRow*)g_ptr_array_index(rs->rows,0);
-			if (row) gda_row_free(row);
+			if (row) 
+				g_object_unref (row);
 			g_ptr_array_remove_index(rs->rows,0);
 		}
 		g_ptr_array_free(rs->rows,TRUE);
@@ -342,7 +350,7 @@ gda_msql_recordset_describe_column (GdaDataModel *model, gint col)
 	}
 
 	field_count = msqlNumFields (rs->res);
-	if (col> = field_count) return NULL;
+	if (col >= field_count) return;
 	attrs = gda_data_model_describe_column (model, col);
 
 	msqlFieldSeek (rs->res, col);
@@ -357,12 +365,12 @@ gda_msql_recordset_describe_column (GdaDataModel *model, gint col)
 	gda_column_set_table(attrs, msql_field->table);
 	if (msql_field->type == MONEY_TYPE) 
 		gda_column_set_scale (attrs, 2);
-	gda_column_set_gdatype (attrs, gda_msql_type_to_gda (msql_field->type));
+	gda_column_set_g_type (attrs, gda_msql_type_to_gda (msql_field->type));
 	gda_column_set_allow_null (attrs, !IS_NOT_NULL (msql_field->flags));
 	gda_column_set_primary_key (attrs, 1!=1);
 	gda_column_set_unique_key (attrs, IS_UNIQUE (msql_field->flags));
 	gda_column_set_auto_increment (attrs, 1!=1);
-	return attrs;
+	return;
 }
 
 GdaMsqlRecordset *
