@@ -85,6 +85,10 @@ static GList *gda_sqlite_provider_execute_command (GdaServerProvider *provider,
 						   GdaCommand *cmd,
 						   GdaParameterList *params);
 
+static gchar *gda_sqlite_provider_get_last_insert_id (GdaServerProvider *provider,
+                                                        GdaConnection *cnc,
+                                                        GdaDataModel *recset);
+
 static gboolean gda_sqlite_provider_begin_transaction (GdaServerProvider *provider,
 						       GdaConnection *cnc,
 						       const gchar *name, GdaTransactionIsolation level,
@@ -124,7 +128,7 @@ static const gchar* gda_sqlite_provider_get_default_dbms_type (GdaServerProvider
 static GObjectClass *parent_class = NULL;
 
 typedef struct {
-        gchar        *col_name;
+        gchar *col_name;
         GType  data_type;
 } GdaSqliteColData;
 
@@ -164,7 +168,7 @@ gda_sqlite_provider_class_init (GdaSqliteProviderClass *klass)
 
 	provider_class->execute_command = gda_sqlite_provider_execute_command;
 	provider_class->execute_query = NULL;
-	provider_class->get_last_insert_id = NULL;
+	provider_class->get_last_insert_id = gda_sqlite_provider_get_last_insert_id;
 
 	provider_class->begin_transaction = gda_sqlite_provider_begin_transaction;
 	provider_class->commit_transaction = gda_sqlite_provider_commit_transaction;
@@ -238,7 +242,7 @@ gda_sqlite_provider_open_connection (GdaServerProvider *provider,
 				     const gchar *username,
 				     const gchar *password)
 {
-	gchar *filename = NULL, *tmp;
+	gchar *filename = NULL;
 	const gchar *dirname = NULL, *dbname = NULL;
 	gint errmsg;
 	SQLITEcnc *scnc;
@@ -253,49 +257,49 @@ gda_sqlite_provider_open_connection (GdaServerProvider *provider,
 	dbname = gda_quark_list_find (params, "DB_NAME");
 
 	if (!dirname || !dbname) {
-		const gchar *str;
+                const gchar *str;
 
-		str = gda_quark_list_find (params, "URI");
-		if (!str) {
-			gda_connection_add_event_string (cnc,
-							 _("The connection string must contain DB_DIR and DB_NAME values"));
-			return FALSE;
-		}
-		else {
-			gint len = strlen (str);
+                str = gda_quark_list_find (params, "URI");
+                if (!str) {
+                        gda_connection_add_event_string (cnc,
+                                                         _("The connection string must contain DB_DIR and DB_NAME values"));
+                        return FALSE;
+                }
+                else {
+                        gint len = strlen (str);
+			gint elen = strlen (FILE_EXTENSION);
 
-			if ((len > 4) && (str[len-1] == 'b') && (str[len-2] == 'd') && (str[len-3] == '.')) {
-				gchar *ptr;
+			if (g_str_has_suffix (str, FILE_EXTENSION)) {
+                                gchar *ptr;
 
-				dup = strdup (str);
-				dup [len-3] = 0;
-				ptr = dup + (len - 4);
-				while ((ptr >= dup) && (*ptr != '/'))
-					ptr--;
-				dbname = ptr;
-				if (*ptr == '/')
-					dbname ++;
+                                dup = strdup (str);
+                                dup [len-elen] = 0;
+                                for (ptr = dup + (len - elen - 1); (ptr >= dup) && (*ptr != G_DIR_SEPARATOR); ptr--);
+                                dbname = ptr;
+                                if (*ptr == G_DIR_SEPARATOR)
+                                        dbname ++;
 
-				if ((*ptr == '/') && (ptr > dup)) {
-					dirname = dup;
-					while ((ptr >= dup) && (*ptr != '/'))
-						ptr--;
-					*ptr = 0;
-				}
-			}
-			if (!dbname || !dirname) {
-				gda_connection_add_event_string (cnc,
-								 _("The connection string format has changed: replace URI with "
-								   "DB_DIR (the path to the database file) and DB_NAME "
-								   "(the database file without the '.db' at the end)."));
-				return FALSE;
-			}
-			else 
-				g_warning (_("The connection string format has changed: replace URI with "
-					     "DB_DIR (the path to the database file) and DB_NAME "
-					     "(the database file without the '.db' at the end)."));
-		}
-	}
+                                if ((*ptr == G_DIR_SEPARATOR) && (ptr > dup)) {
+                                        dirname = dup;
+                                        while ((ptr >= dup) && (*ptr != G_DIR_SEPARATOR))
+                                                ptr--;
+                                        *ptr = 0;
+                                }
+                        }
+                        if (!dbname || !dirname) {
+                                gda_connection_add_event_string (cnc,
+                                                                 _("The connection string format has changed: replace URI with "
+                                                                   "DB_DIR (the path to the database file) and DB_NAME "
+                                                                   "(the database file without the '%s' at the end)."), FILE_EXTENSION);
+				g_free (dup);
+                                return FALSE;
+                        }
+                        else
+                                g_warning (_("The connection string format has changed: replace URI with "
+                                             "DB_DIR (the path to the database file) and DB_NAME "
+                                             "(the database file without the '%s' at the end)."), FILE_EXTENSION);
+                }
+        }	
 
 	if (!g_file_test (dirname, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
 		gda_connection_add_event_string (cnc,
@@ -305,10 +309,18 @@ gda_sqlite_provider_open_connection (GdaServerProvider *provider,
 		return FALSE;
 	}
 
-	tmp = g_strdup_printf ("%s%s", dbname, FILE_EXTENSION);
-	filename = g_build_filename (dirname, tmp, NULL);
+	/* try first without the file extension */
+	filename = g_build_filename (dirname, dbname, NULL);
+	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		gchar *tmp;
+		g_free (filename);
+		tmp = g_strdup_printf ("%s%s", dbname, FILE_EXTENSION);
+		filename = g_build_filename (dirname, tmp, NULL);
+		g_free (tmp);
+		
+	}
 	g_free (dup);
-	g_free (tmp);
+
 	scnc = g_new0 (SQLITEcnc, 1);
 
 	errmsg = sqlite3_open (filename, &scnc->connection);
@@ -324,7 +336,12 @@ gda_sqlite_provider_open_connection (GdaServerProvider *provider,
 		return FALSE;
 	}
 
+	/* use extended result codes */
+	sqlite3_extended_result_codes (scnc->connection, 1);
 	g_object_set_data (G_OBJECT (cnc), OBJECT_DATA_SQLITE_HANDLE, scnc);
+	
+	/* allow a busy timeout of 500 ms */
+	sqlite3_busy_timeout (scnc->connection, 500);
 
 	/* set SQLite library options */
 	if (!gda_sqlite_provider_single_command (sqlite_prv, cnc, "PRAGMA empty_result_callbacks = ON"))
@@ -452,7 +469,7 @@ process_sql_commands (GList *reclist, GdaConnection *cnc,
 			copy = g_strdup (arr[n]);
 			sres = g_new0 (SQLITEresult, 1);
 
-			status = sqlite3_prepare (scnc->connection, arr [n], -1, &(sres->stmt), &left);
+			status = sqlite3_prepare_v2 (scnc->connection, arr [n], -1, &(sres->stmt), &left);
 			if (left && (*left != 0))
 				g_warning ("SQlite SQL: %s (REMAIN:%s)\n", arr [n], left);
 
@@ -480,11 +497,15 @@ process_sql_commands (GList *reclist, GdaConnection *cnc,
 					status = sqlite3_step (sres->stmt);
 					changes = sqlite3_changes (scnc->connection);
 					if (status != SQLITE_DONE) {
-						error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
-						gda_connection_event_set_description (error, sqlite3_errmsg (scnc->connection));
-						gda_connection_add_event (cnc, error);
-						reclist = g_list_append (reclist, NULL);
-						allok = FALSE;
+						if (sqlite3_errcode (scnc->connection) != SQLITE_OK) {
+							sqlite3_reset (sres->stmt);
+							error = gda_connection_event_new (GDA_CONNECTION_EVENT_ERROR);
+							gda_connection_event_set_description (error, 
+											      sqlite3_errmsg (scnc->connection));
+							gda_connection_add_event (cnc, error);
+							reclist = g_list_append (reclist, NULL);
+							allok = FALSE;
+						}
 					}
 					else {
 						/* don't return a data model */
@@ -498,7 +519,8 @@ process_sql_commands (GList *reclist, GdaConnection *cnc,
 
 					/* generate a notice about changes */
 					if (allok) {
-						event = gda_connection_event_new (GDA_CONNECTION_EVENT_NOTICE);
+						str = NULL;
+						
 						ptr = tststr;
 						while (*ptr && (*ptr != ' ') && (*ptr != '\t') &&
 						       (*ptr != '\n'))
@@ -513,14 +535,27 @@ process_sql_commands (GList *reclist, GdaConnection *cnc,
 								str = g_strdup_printf ("%s %lld %d", tmp, 
 										       sqlite3_last_insert_rowid (scnc->connection),
 										       changes);
-							else
-								str = g_strdup_printf ("%s %d", tmp, changes);
+							else {
+								if (!strncmp (tmp, "DELETE", 6))
+									str = g_strdup_printf ("%s %d", tmp, changes);
+								else {
+									if (*tmp) {
+										if (changes > 0)
+											str = g_strdup_printf ("%s %d", tmp, 
+													       changes);
+										else
+											str = g_strdup (tmp);
+									}
+								}
+							}
 						}
 						
-						
-						gda_connection_event_set_description (event, str);
-						g_free (str);
-						gda_connection_add_event (cnc, event);
+						if (str) {
+							event = gda_connection_event_new (GDA_CONNECTION_EVENT_NOTICE);
+							gda_connection_event_set_description (event, str);
+							g_free (str);
+							gda_connection_add_event (cnc, event);
+						}
 					}
 				}
 			} 
@@ -626,10 +661,10 @@ gda_sqlite_provider_create_operation (GdaServerProvider *provider, GdaConnection
         file = g_utf8_strdown (gda_server_operation_op_type_to_string (type), -1);
         str = g_strdup_printf ("sqlite_specs_%s.xml", file);
         g_free (file);
-        file = g_build_filename (LIBGDA_DATA_DIR, str, NULL);
+        file = gda_server_provider_find_file (provider, LIBGDA_DATA_DIR, str);
         g_free (str);
 
-        if (! g_file_test (file, G_FILE_TEST_EXISTS)) {
+        if (! file) {
                 g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
                 return NULL;
         }
@@ -651,10 +686,10 @@ gda_sqlite_provider_render_operation (GdaServerProvider *provider, GdaConnection
         file = g_utf8_strdown (gda_server_operation_op_type_to_string (gda_server_operation_get_op_type (op)), -1);
         str = g_strdup_printf ("sqlite_specs_%s.xml", file);
         g_free (file);
-        file = g_build_filename (LIBGDA_DATA_DIR, str, NULL);
+        file = gda_server_provider_find_file (provider, LIBGDA_DATA_DIR, str);
         g_free (str);
 
-        if (! g_file_test (file, G_FILE_TEST_EXISTS)) {
+        if (! file) {
                 g_set_error (error, 0, 0, _("Missing spec. file '%s'"), file);
                 return NULL;
         }
@@ -847,6 +882,37 @@ gda_sqlite_provider_execute_command (GdaServerProvider *provider,
 	return reclist;
 }
 
+static gchar *
+gda_sqlite_provider_get_last_insert_id (GdaServerProvider *provider,
+					GdaConnection *cnc,
+					GdaDataModel *recset)
+{
+	GdaSqliteProvider *sqlite_prv = (GdaSqliteProvider *) provider;
+	SQLITEcnc *scnc;
+	long long int rowid;
+
+        g_return_val_if_fail (GDA_IS_SQLITE_PROVIDER (sqlite_prv), NULL);
+        g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+
+        scnc = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_SQLITE_HANDLE);
+        if (!scnc) {
+                gda_connection_add_event_string (cnc, _("Invalid SQLite handle"));
+                return NULL;
+        }
+
+ 	if (recset) {
+		g_return_val_if_fail (GDA_IS_SQLITE_RECORDSET (recset), NULL);
+		TO_IMPLEMENT;
+		return NULL;
+	}
+	rowid = sqlite3_last_insert_rowid (scnc->connection);
+	if (rowid != 0)
+		return g_strdup_printf ("%lld", rowid);
+	else
+		return NULL;
+}
+
+
 static gboolean
 gda_sqlite_provider_begin_transaction (GdaServerProvider *provider,
 				       GdaConnection *cnc,
