@@ -1,5 +1,5 @@
 /* GDA Postgres Provider
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2007 The GNOME Foundation
  *
  * AUTHORS:
  *         Vivien Malerba <malerba@gnome-db.org>
@@ -21,14 +21,24 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
+#include <libgda/gda-config.h>
 #include "gda-sqlite-provider.h"
+#include <libgda/gda-server-provider-extra.h>
 
-const gchar *plugin_get_name (void);
-const gchar *plugin_get_description (void);
-GList *plugin_get_connection_params (void);
+static gchar      *module_path = NULL;
+const gchar       *plugin_get_name (void);
+const gchar       *plugin_get_description (void);
+gchar             *plugin_get_dsn_spec (void);
 GdaServerProvider *plugin_create_provider (void);
 
+void
+plugin_init (const gchar *real_path)
+{
+        if (real_path)
+                module_path = g_strdup (real_path);
+}
+
 const gchar *
 plugin_get_name (void)
 {
@@ -38,21 +48,21 @@ plugin_get_name (void)
 const gchar *
 plugin_get_description (void)
 {
-	return _("GDA provider for SQLite databases");
+	return _("Provider for SQLite databases");
 }
 
-GList *
-plugin_get_connection_params (void)
+gchar *
+plugin_get_dsn_spec (void)
 {
-	GList *list = NULL;
-
-	list = g_list_append (list, g_strdup ("URI"));
-
-	return list;
+	return gda_server_provider_load_file_contents (module_path, LIBGDA_DATA_DIR, "sqlite_specs_dsn.xml");
 }
 
 GdaServerProvider *
 plugin_create_provider (void)
 {
-	return gda_sqlite_provider_new ();
+	GdaServerProvider *prov;
+
+        prov = gda_sqlite_provider_new ();
+        g_object_set_data (prov, "GDA_PROVIDER_DIR", module_path);
+        return prov;
 }
